Garment
=======

A collection of fabric_ tasks that roll up into a single deploy function. The
whole process is coordinated through a single deployment configuration file
named ``deploy.conf``

For more information see the full documentation: http://garment.readthedocs.org/

.. _fabric: http://fabfile.org